labeltools.color_note_head_by_numbered_pitch_class_color_map
============================================================

.. autofunction:: abjad.tools.labeltools.color_note_head_by_numbered_pitch_class_color_map.color_note_head_by_numbered_pitch_class_color_map
